@@ -1,28 +1,20 @@
-import sys
-import json
-import getpass
-import argparse
 from Crypto.Cipher import AES
 import binascii
-import random
-import time
-import os
-import pyperclip
-import requests
-import base64
-import socket
 from onepasswd import ltlog
 from Crypto.PublicKey import RSA
 from hashlib import sha256
 
 log = ltlog.getLogger('onepasswd.crypto')
 
+
 class WrongPasswordException(Exception):
     pass
 
+
 def hash_key(key):
     return sha256(sha256(key.encode()).hexdigest().encode()).hexdigest()
 
+
 def decrypt_passwd(passwd_enc, key):
     key = binascii.unhexlify(hash_key(key))
     passwd_enc = binascii.unhexlify(passwd_enc)
@@ -30,6 +22,7 @@ def decrypt_passwd(passwd_enc, key):
     passwd = cipher.decrypt(passwd_enc)
     return passwd.decode().strip()
 
+
 def encrypt_passwd(passwd, key):
     key = binascii.unhexlify(hash_key(key))
     passwd = passwd.encode()
@@ -53,7 +46,7 @@ def generate_auth_info(passwd):
 def auth(auth_info, passwd):
     try:
         priv = RSA.importKey(auth_info['priv'], passphrase=passwd)
-    except:
+    except Exception:
         return False
     pub = RSA.importKey(auth_info['pub'])
     result = priv.publickey() == pub
